@@ -688,7 +688,7 @@ def empty_function(no_args):
 def apply_whole(
     function_name, myfile_path="", modified_file_path=""
 ):
-    mylist = text2list(myfile_path=myfile_path, mylist=[])
+    mylist = text2list(myfile_path=myfile_path)
 
     # mylist = [function_name(item) for item in mylist]
     newlist = list(map(function_name, mylist))
